function [SPL_airframe,p_2_airframe] = airframe_noise(conf,h,r_,rho_inf,T_inf,M_inf,a_inf,p_ref,phi,theta,bw,Sw,bv,Sv,n_strut_main,n_wheels_main,d_tyre_main,l_strut_main,n_strut_for,n_wheels_for,d_tyre_for,l_strut_for)

%This function computes airframe noise from configuration and design data.

%% ************************ Airframe noise ********************************

%*************************************************************************%
%*************** 1. Clean delta wing (trailing edge noise)****************%
%*************************************************************************%                            

%*************************************************************************%
%***************** a.  RMS normalized acoustic pressure ******************%
%*****************         p*^2 = p^2/(rho^2*a^4)      *******************%
%*************************************************************************%

f = [50 63 80 100 125 160 200 250 315 400 500 630 800 1000 1250 1600 2000 2500 3150 4000 5000 6300 8000 10000];
rs_ad = r_/bw; 

% -  Overall Power 
mu = 1.81*10e-5; % Air viscosity  [Pa/s]
delta_w = 0.37*(Sw/bw^2)*((rho_inf*M_inf*a_inf*Sw)/(mu*bw))^-0.2; % Turbolent shear layer

K_1 = 7.075*10e-6; 
a_1 = 5; 
G_1 = delta_w; 

[Overall_power_1] = compute_overall_power_air(K_1,M_inf,a_1,G_1); 

%  - Directivity function
Directivity_function_1= 4*((cosd(phi))^2)*((cosd(theta/2))^2);

% - Spectrum function
Str_w = ((f*delta_w*bw)./(M_inf*a_inf)).*(1-M_inf*cosd(theta)); % Strouhal number
Spectrum_function_1 = 0.485.*(10.*Str_w).^(4).*((10.*Str_w).^(1.35)+0.5).^(-4);

% --> compute
[p_2_1] = compute_p_2_air(Overall_power_1,Directivity_function_1, Spectrum_function_1,rs_ad,M_inf,theta);

%*************************************************************************%
%******************** b. Sound Pressure Level (SPL) **********************%
%************ SPL = 10*log(p*^2)+20*log((rho(h_s)*a_inf^2)/p_ref) ********%
%*************************************************************************%

[SPL_1] = compute_SPL(p_2_1,rho_inf,a_inf,p_ref,T_inf,h);

%*************************************************************************%
%****************2. Vertical tail (trailing edge noise)*******************%
%*************************************************************************%

%*************************************************************************%
%***************** a.  RMS normalized acoustic pressure ******************%
%*****************         p*^2 = p^2/(rho^2*a^4)      *******************%
%*************************************************************************%

% -  Overall Power 
delta_v = 0.37*(Sv/bv^2)*((rho_inf*M_inf*a_inf*Sv)/(mu*bv))^-0.2; % Turbolent shear layer

K_2 = 7.075*10e-6; 
a_2 = 5; 
G_2 = delta_v*(bv/bw)^2; 

[Overall_power_2] = compute_overall_power_air(K_2,M_inf,a_2,G_2); 

%  - Directivity function
Directivity_function_2 = 4*((sind(phi))^2)*((cosd(theta/2))^2);

% - Spectrum function
Str_v = ((f*delta_v*bv)./(M_inf*a_inf)).*(1-M_inf*cosd(theta)); % Strouhal number
Spectrum_function_2 = 0.613.*(10.*Str_v).^(4).*((10.*Str_v).^(1.5)+0.5).^(-4);

% --> compute
[p_2_2] = compute_p_2_air(Overall_power_2,Directivity_function_2, Spectrum_function_2, rs_ad,M_inf,theta);

%*************************************************************************%
%******************** b. Sound Pressure Level (SPL) **********************%
%************ SPL = 10*log(p*^2)+20*log((rho(h_s)*a_inf^2)/p_ref) ********%
%*************************************************************************%

% [SPL_2] = compute_SPL(p_2_2,rho_inf,a_inf,p_ref,T_inf,h);

%*************************************************************************%
%*********************3. Landing gear (wheels & strut)********************%
%*************************************************************************%

%************** MAIN LANDING GEAR: 2 strut, 4 wheels per strut************%

%*************************************************************************%
%***************** a.  RMS normalized acoustic pressure ******************%
%*****************         p*^2 = p^2/(rho^2*a^4)      *******************%
%*************************************************************************%

if conf == 1 % Landing gear extracted
    
%***** Wheels: 

% -  Overall Power

K_3a = 3.414*10e-4; 
a_3a = 6;
G_3a = n_wheels_main*(d_tyre_main/bw)^2;

[Overall_power_3a1] = compute_overall_power_air(K_3a,M_inf,a_3a,G_3a); 
[Overall_power_3a] = n_strut_main*Overall_power_3a1;

%  - Directivity function
Directivity_function_3a= (3/2).*((sind(theta))); %It does not depend on phi

% - Spectrum function
Str_lgm = ((f*d_tyre_main)./(M_inf*a_inf)).*(1-M_inf*cosd(theta)); % Strouhal number
Spectrum_function_3a = 0.0577.*(Str_lgm).^(2).*((1+0.25.*Str_lgm.^2).^(-1.5));

% --> compute
[p_2_3a] = compute_p_2_air(Overall_power_3a,Directivity_function_3a, Spectrum_function_3a, rs_ad,M_inf,theta);

%*************************************************************************%
%******************** b. Sound Pressure Level (SPL) **********************%
%************ SPL = 10*log(p*^2)+20*log((rho(h_s)*a_inf^2)/p_ref) ********%
%*************************************************************************%

%[SPL_3a] = compute_SPL(p_2_3a,rho_inf,a_inf,p_ref,T_inf,h);

%****** Strut:

% -  Overall Power
K_3b = 2.753*10e-4;
a_3b = 6;
G_3b = (l_strut_main/bw); 

[Overall_power_3b1] = compute_overall_power_air(K_3b,M_inf,a_3b,G_3b); 
[Overall_power_3b] = n_strut_main*Overall_power_3b1;

%  - Directivity function
Directivity_function_3b = (3).*((sind(theta))^2).*((sind(phi))^2);

% - Spectrum function
Str_lgm = ((f*d_tyre_main)./(M_inf*a_inf)).*(1-M_inf*cosd(theta)); % Strouhal number
Spectrum_function_3b = 1.280.*(Str_lgm).^(3).*((1.06+Str_lgm.^2).^(-3));

% --> compute
[p_2_3b] = compute_p_2_air(Overall_power_3b,Directivity_function_3b, Spectrum_function_3b, rs_ad,M_inf,theta);

%*************************************************************************%
%******************** b. Sound Pressure Level (SPL) **********************%
%************ SPL = 10*log(p*^2)+20*log((rho(h_s)*a_inf^2)/p_ref) ********%
%*************************************************************************%

%[SPL_3b] = compute_SPL(p_2_3b,rho_inf,a_inf,p_ref,T_inf,h);

%TOTAL: SOUND PRESSURE LEVEL MAIN LANDING GEAR

p_2_3_main = p_2_3a+p_2_3b;
% [SPL_main] = compute_SPL(p_2_3_main,rho_inf,a_inf,p_ref,T_inf,h);

%************ FORWARD LANDING GEAR: 1 strut, 2 wheels per strut***********%

%*************************************************************************%
%***************** a.  RMS normalized acoustic pressure ******************%
%*****************         p*^2 = p^2/(rho^2*a^4)      *******************%
%*************************************************************************%

%***** Wheels: 

% -  Overall Power

K_3c = 4.349*10e-4; 
a_3c = 6;
G_3c = n_wheels_for*(d_tyre_for/bw)^2; 

[Overall_power_3c1] = compute_overall_power_air(K_3c,M_inf,a_3c,G_3c); 
[Overall_power_3c] = n_strut_for*Overall_power_3c1;

%  - Directivity function

% theta_ = linspace(0,2*pi); %polar directivity angle [rad]
% phi_ =  linspace(0,2*pi);%azimuthal directivity angle [rad]
% Directivity_function_total_3c = (3/2).*((sin(theta_)));

% Same directivity of Main landing gear !
Directivity_function_3c = (3/2).*((sind(theta))); %It does not depend on phi

% - Spectrum function
Str_lgf = ((f*d_tyre_for)./(M_inf*a_inf)).*(1-M_inf*cosd(theta)); % Strouhal number
Spectrum_function_3c = 13.59.*(Str_lgf).^(2).*((12.5+Str_lgf.^2).^(-2.25));

% --> compute
[p_2_3c] = compute_p_2_air(Overall_power_3c,Directivity_function_3c, Spectrum_function_3c,rs_ad,M_inf,theta);

%*************************************************************************%
%******************** b. Sound Pressure Level (SPL) **********************%
%************ SPL = 10*log(p*^2)+20*log((rho(h_s)*a_inf^2)/p_ref) ********%
%*************************************************************************%

% [SPL_3c] = compute_SPL(p_2_3c,rho_inf,a_inf,p_ref,T_inf,h);

%****** Strut:

% -  Overall Power
K_3d = 2.753*10e-4; 
a_3d = 6;
G_3d = (l_strut_for/bw); 

[Overall_power_3d] = compute_overall_power_air(K_3d,M_inf,a_3d,G_3d); 
 

%  - Directivity function
Directivity_function_3d = (3).*((sind(theta))^2).*((sind(phi))^2);

% - Spectrum function
Str_lgf = ((f*d_tyre_for)./(M_inf*a_inf)).*(1-M_inf*cosd(theta)); % Strouhal number
Spectrum_function_3d = 5.325.*(Str_lgf).^(2).*((30+Str_lgf.^8).^(-1));

% --> compute
[p_2_3d] = compute_p_2_air(Overall_power_3d,Directivity_function_3d, Spectrum_function_3d, rs_ad,M_inf,theta);

%*************************************************************************%
%******************** b. Sound Pressure Level (SPL) **********************%
%************ SPL = 10*log(p*^2)+20*log((rho(h_s)*a_inf^2)/p_ref) ********%
%*************************************************************************%

%[SPL_3d] = compute_SPL(p_2_3d,rho_inf,a_inf,p_ref,T_inf,h);

%TOTAL: SOUND PRESSURE LEVEL FORWARD LANDING GEAR

p_2_3_for = p_2_3c+p_2_3d;
%[SPL_for] = compute_SPL(p_2_3_for,rho_inf,a_inf,p_ref,T_inf,h);

%************TOTAL: SOUND PRESSURE LEVEL LANDING GEAR*********************%

p_2_3 = p_2_3_main+p_2_3_for;
[SPL_3] = compute_SPL(p_2_3,rho_inf,a_inf,p_ref,T_inf,h);

elseif conf == 0 % Landing-gear retracted
    
    p_2_3 = 0;
    
end

%*************************************************************************%
% ********  ******* ****** TOTAL AIRFRAME NOISE ******* ******* ******* %

p_2_airframe = p_2_1+p_2_2+p_2_3;
[SPL_airframe] = compute_SPL(p_2_airframe,rho_inf,a_inf,p_ref,T_inf,r_);

end

