function [rho_0,T_0,p_0,a_inf,M_inf] = atmospheric_model(h_pt,V)

% This function computes density, temperature and pressure from input
% altitude by ISA atmospheric model (troposphere). It also computes the
% speed of sound, Mach (from V input).

h = 1:11000; % Altitude [m]

rho_sl = 1.225; % Seal level air density [kg/m^3]

T_sl = 256.15; % Sea level temperature [K]
gt = -6.5/1000; % Thermal gradient [K/m]

for i = 1: length(h)
    
    T(i) = T_sl+gt*h(i);
    rho(i) = rho_sl*(T(i)/T_sl).^(4.25);
    i = i+1;
    
end

p_sl = 101325; % Sea level pressure [Pa]

for i = 1: length(h)
    
    p(i) = p_sl*((T(i)/T_sl)).^5.256;
    
    i = i+1;
    
end

% Output:

% Ambient conditions
rho_0 = rho(h_pt);
T_0 = T(h_pt);
p_0 = p(h_pt);

% Speed of sound [m/s]
R_spec = 287; % Gas specific constant[J/KgK]
gamma = 1.4; 
a_inf = sqrt(gamma*R_spec*T_0);

% Mach  number
M_inf = abs(V)./a_inf; 

end

