function [p_2_fan, p_2_fan_1a, p_2_fan_1b, p_2_fan_1c, p_2_fan_1d_8, p_2_fan_1d_4, p_2_fan_1d_2, p_2_fan_2a, p_2_fan_2b] = compute_p_2_fan(ne,T_inf,rho_inf,M_inf,a_inf,r_,theta,Ae,d_rot,A_fan,i,nV,N,B,C,s,l,Md,mdot_off,delta_T)

%This function compute fan noise from engine parameters.

r_ad = r_/Ae;
N_ad = N*d_rot/a_inf;
Mt = pi*N_ad; % Rotor tip Mach number

mdot_ad = (mdot_off)/(rho_inf*a_inf*Ae);

A_fan_ad = A_fan/Ae;

delta_fan = Mt/abs(1-nV/B); % Cut-off factor (N.B.: the cut-off factor determines the range of the tip Mach number where the fundamental blade passing frequency dominates).

if delta_fan > 1.05
    j = 1;
else
    j = 2;
end

s_ad = s/C;

if s_ad <= 1
    k = 1;
else 
    k = 2;
end

f = [50 63 80 100 125 160 200 250 315 400 500 630 800 1000 1250 1600 2000 2500 3150 4000 5000 6300 8000 10000]; %frequenze centrali tra 50 e 10000 Hz in 1/3 di ottava
fb = (N_ad*B*a_inf)/(d_rot*sqrt(Ae)); % Blade passing frequency
eta = (1-M_inf*cosd(theta))*f/fb;

Mm = max(1,Md);

% Hyp: inlet static density and speed of sound are assumed equal to the
% ambient values --> Mx (axial tip Mach number = mdot_ad/A_fan_ad)

Mx = mdot_ad/A_fan_ad;  % Axial tip Mach number
Mr = sqrt(Mt^2 + Mx^2);  % Relative tip Mach Number

delta_T_ad = delta_T/T_inf;

%*************************************************************************%
%****************************** 1. Inlet  ********************************%
%*********************** 1a. Total broadband noise ***********************%

%*************************************************************************%
%***************** a.  RMS normalized acoustic pressure ******************%
%*****************         p*^2 = p^2/(rho^2*a^4)      *******************%
%*************************************************************************%

% -  Overall Power 
K_inlet_B = 1.552*10^(-4);

G_inlet_B = 1;

a = [0.5 0.5; 0.5 0];
a_inlet_B = a(k,l);

b_inlet_B = 2;

if Mr <= 0.9
    F_inlet_B = 1;
else
    F_inlet_B = 0.81*Mr^(-0.2);
end

[Overall_power_fan_1a] = compute_overall_power_fan(K_inlet_B,1,s_ad,a_inlet_B,Mm,b_inlet_B,mdot_ad,A_fan_ad,delta_T_ad,F_inlet_B);

% - Directivity function D(theta)
theta_deg = [0 10 20 30 40 50 60 70 80 90 100 110 120 130 140 150 160 170 180];
directivity_level_log10D_InletBroad = [0.43 0.53 0.63 0.63 0.63 0.43 0.18 -0.12 -0.47 -0.87 -1.32 -1.87 -2.42 -2.97 -3.52 -4.07 -4.62 -5.17 -5.72];

%Coefficients (with 95% confidence bounds):
       p1 =   1.264e-06;
       p2 =  -0.0005604;
       p3 =     0.02609;
       p4 =      0.3649;

D_inlet_B = 10^(p1*(theta)^3 + p2*(theta)^2 + p3*(theta) + p4);


% - Spectrum function S(eta)
S_inlet_B = 0.116.*exp(-0.5.*(log10(eta./2.5)./log10(2.2)).^2);

%--> compute
p_2_fan_1a = ((A_fan_ad*Overall_power_fan_1a)/(4*pi*r_ad^2))*(D_inlet_B*S_inlet_B)/(1-M_inf*cosd(theta)^4);

%*************************************************************************%
%****************************** 1. Inlet  ********************************%
%******************* 1b. Rotor-stator interaction tones ******************%

%*************************************************************************%
%***************** a.  RMS normalized acoustic pressure ******************%
%*****************         p*^2 = p^2/(rho^2*a^4)      *******************%
%*************************************************************************%

% -  Overall Power 
K_inlet_IT = 2.683*10^(-4);

G = [1 0.580; 0.625 0.205];
G_inlet_IT = G(i,j);

a = [1 1; 1 0];
a_inlet_T = a(k,l);

b_inlet_T = 4.31;

if Mr <= 0.72
    F_inlet_T = 0.397*Mm^(-2.31);
elseif (Mr > 0.72) && (Mr <= 0.866*Mm^(0.462))
    F_inlet_T = 2.053*Mm^(-2.31)*Mr^5;
else
    F_inlet_T = 0.315*Mm^(3.69)*Mr^(-8);
end

[Overall_power_fan_1b] = compute_overall_power_fan(K_inlet_IT,G_inlet_IT,s_ad,a_inlet_T,Mm,b_inlet_T,mdot_ad,A_fan_ad,delta_T_ad ,F_inlet_T);

% - Directivity function D(theta)
directivity_level_log10D_InletDiscreteTone = [0.30 0.45 0.60 0.60 0.60 0.48 0.25 -0.08 -0.45 -0.85 -1.30 -1.85 -2.40 -2.95 -3.50 -4.05 -4.60 -5.15 -5.70];

%Coefficients (with 95% confidence bounds):
       p1 =   1.407e-06;
       p2 =  -0.0006093;
       p3 =     0.03114;
       p4 =       0.238;
       
D_inlet_T = 10^(p1*(theta)^3 + p2*(theta)^2 + p3*(theta) + p4);


% - Spectrum function S(eta)
for p = 1:length(f) % Number of bands
    n_low(p) = round((10.^(-1/20.*eta(p))+1)); % Lowest harmonic number
    n_upper(p) = round((10.^(1/20.*eta(p))));  % Highest harmonic number
    
     if n_low(p) > n_upper(p)
     S_inlet_IT(p) = 0; % No tone in the band centered in the 1/3 octave centered frequency with eta(p) frequency parameter

     elseif n_low(p) <= n_upper(p) % [n_upper(p)-n_low(p)+1] tones in the band centered in the 1/3 octave centered frequency with eta(p) frequency parameter
     
         n = n_low(p):n_upper(p);
         for  q = 1:length(n)
              if n(q) == 1
              S_inlet_IT_1 = [0.499 0.136; 0.799 0.387];
              S_inlet_IT_(q) = S_inlet_IT_1(i,j);
              else
              S_inlet_IT_n = [0.250 0.432; 0.101 0.307].*(10.^(-0.3*(n(q)-2)));
              S_inlet_IT_(q) = S_inlet_IT_n(i,j);
              end
              
              S_inlet_IT(p) = sum(S_inlet_IT_);
         end
          
    end
 end


%--> compute
p_2_fan_1b = ((A_fan_ad*Overall_power_fan_1b)/(4*pi*r_ad^2))*(D_inlet_T*S_inlet_IT)/(1-M_inf*cosd(theta)^4);

%*************************************************************************%
%****************************** 1. Inlet  ********************************%
%******************** 1c. Rotor-stator distorsion tones ******************%

%*************************************************************************%
%***************** a.  RMS normalized acoustic pressure ******************%
%*****************         p*^2 = p^2/(rho^2*a^4)      *******************%
%*************************************************************************%

% -  Overall Power 
K_inlet_DT = 1.488*10^(-4);
G_inlet_DT = 1;

[Overall_power_fan_1c] = compute_overall_power_fan(K_inlet_DT,G_inlet_DT,s_ad,a_inlet_T,Mm,b_inlet_T,mdot_ad,A_fan_ad,delta_T_ad,F_inlet_T);

% - Directivity function D(theta) -> the same of interaction tones

% - Spectrum function S(eta)
for p = 1:length(f) % Number of bands
    n_low(p) = round((10.^(-1/20.*eta(p))+1)); % Lowest harmonic number
    n_upper(p) = round((10.^(1/20.*eta(p))));  % Highest harmonic number
    
     if n_low(p) > n_upper(p)
     S_inlet_DT(p) = 0; % No tone in the band centered in the 1/3 octave centered frequency with eta(p) frequency parameter

     elseif n_low(p) <= n_upper(p) % [n_upper(p)-n_low(p)+1] tones in the band centered in the 1/3 octave centered frequency with eta(p) frequency parameter
     
         n = n_low(p):n_upper(p);
         for  q = 1:length(n)
              S_inlet_DT_(q) = 9*sum(10^-n(q));         
         end
          
              S_inlet_DT(p) = sum(S_inlet_DT_);
 
    end
 end

%--> compute
p_2_fan_1c = ((A_fan_ad*Overall_power_fan_1c)/(4*pi*r_ad^2))*(D_inlet_T*S_inlet_DT)/(1-M_inf*cosd(theta)^4);

%*************************************************************************%
%****************************** 1. Inlet  ********************************%
%************************* 1d. Combination tones *************************%

%*************************************************************************%
%***************** a.  RMS normalized acoustic pressure ******************%
%*****************         p*^2 = p^2/(rho^2*a^4)      *******************%
%*************************************************************************%

% - Overall Power 

% 1/8 fundamental combination tone
K_inlet_CT_8 = 6.225*10^(-4);

if Mr < 1
    F_inlet_CT_8 = 0;
elseif (Mr >= 1) && (Mr <= 1.61)
    F_inlet_CT_8 = 10^(-6.75*(1.61-Mr));
else
    F_inlet_CT_8 = 10^(-1.21*(Mr-1.61));
end

% 1/4 fundamental combination tone
K_inlet_CT_4 = 2.030*10^(-3);

if Mr < 1
    F_inlet_CT_4 = 0;
elseif (Mr >= 1) && (Mr <= 1.322)
    F_inlet_CT_4 = 10^(-14.75*(1.322-Mr));
else
    F_inlet_CT_4 = 10^(-1.33*(Mr-1.322));
end

% 1/2 fundamental combination tone
K_inlet_CT_2 = 2.525*10^(-3);

if Mr < 1
    F_inlet_CT_2 = 0;
elseif (Mr >= 1) && (Mr <= 1.146)
    F_inlet_CT_2 = 10^(-31.85*(1.146-Mr));
else
    F_inlet_CT_2 = 10^(-1.41*(Mr-1.146));
end

G = [1 1; 0.316 0.316];
G_inlet_CT = G(i,j);


[Overall_power_fan_1d_8] = compute_overall_power_fan(K_inlet_CT_8,G_inlet_CT,1,1,1,1,mdot_ad,A_fan_ad,delta_T_ad,F_inlet_CT_8);

[Overall_power_fan_1d_4] = compute_overall_power_fan(K_inlet_CT_4,G_inlet_CT,1,1,1,1,mdot_ad,A_fan_ad,delta_T_ad,F_inlet_CT_4);

[Overall_power_fan_1d_2] = compute_overall_power_fan(K_inlet_CT_2,G_inlet_CT,1,1,1,1,mdot_ad,A_fan_ad,delta_T_ad,F_inlet_CT_2);

% - Directivity function D(theta)
directivity_level_log10D_InletCombTone = [-0.43 -0.33 -0.18 0.02 0.32 0.52 0.52 0.17 -0.23 -0.38 -0.43 -0.48 -0.53 -0.58 -0.63 -0.68 -0.73 -0.78 -0.83];

    ind = find(theta == theta_deg);
    if isempty(ind)
        i1 = find(theta_deg < theta,1,'last');
        i2 = find(theta_deg > theta,1,'first');
        D_inlet_CT = 10^(directivity_level_log10D_InletCombTone(i1))+(((theta-theta_deg(i1))/(theta_deg(i2) - theta_deg(i1)))*(directivity_level_log10D_InletCombTone(i2)-(directivity_level_log10D_InletCombTone(i1))));
    else
        D_inlet_CT = 10^directivity_level_log10D_InletCombTone(ind);
    end


% - Spectrum function S(eta)
for p = 1:length(f)
if eta(p) <= 0.125 
    S_inlet_CT_8(p) = 0.405*(8*eta(p))^(5);
else
    S_inlet_CT_8(p) = 0.405*(8*eta(p))^(-3);
end
end


for p = 1:length(f)
if eta(p) <= 0.25
    S_inlet_CT_4(p) = 0.520*(4*eta(p))^(5);
else
    S_inlet_CT_4(p) = 0.520*(4*eta(p))^(-5);
end
end



for p = 1:length(f)
if eta(p) <= 0.5
    S_inlet_CT_2(p) = 0.332*(2*eta(p))^(3);
else
    S_inlet_CT_2(p) = 0.332*(2*eta(p))^(-3);
end
end

%--> compute
p_2_fan_1d_8 = ((A_fan_ad*Overall_power_fan_1d_8)/(4*pi*r_ad^2))*(D_inlet_CT*S_inlet_CT_8)/(1-M_inf*cosd(theta)^4);

p_2_fan_1d_4 = ((A_fan_ad*Overall_power_fan_1d_4)/(4*pi*r_ad^2))*(D_inlet_CT*S_inlet_CT_4)/(1-M_inf*cosd(theta)^4);

p_2_fan_1d_2 = ((A_fan_ad*Overall_power_fan_1d_2)/(4*pi*r_ad^2))*(D_inlet_CT*S_inlet_CT_2)/(1-M_inf*cosd(theta)^4);

%*************************************************************************%
%*************************** 2. Discharge  *******************************%
%*********************** 2a. Total broadband noise ***********************%

%*************************************************************************%
%***************** a.  RMS normalized acoustic pressure ******************%
%*****************         p*^2 = p^2/(rho^2*a^4)      *******************%
%*************************************************************************%

% -  Overall Power 
K_dis_B = 3.206*10^(-4);

G = [1 1; 2 2];
G_dis_B = G(i,j);

a_dis_B = a_inlet_B;

b_dis_B = b_inlet_B;

if Mr <= 1
    F_dis_B = 1;
else
    F_dis_B = Mr^(-2);
end

[Overall_power_fan_2a] = compute_overall_power_fan(K_dis_B,G_dis_B,s_ad,a_dis_B,Mm,b_dis_B,mdot_ad,A_fan_ad,delta_T_ad,F_dis_B);

% - Directivity function D(theta)
directivity_level_log10D_DisBroad = [-3.70 -3.27 -2.84 -2.41 -1.98 -1.55 -1.12 -0.69 -0.34 -0.04 0.19 0.34 0.43 0.46 0.26 -0.14 -0.54 -1.04 -1.54];

%Coefficients (with 95% confidence bounds):
       p1 =  -1.871e-06;
       p2 =   0.0001806;
       p3 =     0.03942;
       p4 =      -3.701;
       
D_dis_B = 10^(p1*(theta)^3 + p2*(theta)^2 + p3*(theta) + p4);

% - Spectrum function S(eta)
S_dis_B = S_inlet_B;

%--> compute

p_2_fan_2a = ((A_fan_ad*Overall_power_fan_2a)/(4*pi*r_ad^2))*(D_dis_B*S_dis_B)/(1-M_inf*cosd(theta)^4);

%*************************************************************************%
%*************************** 2. Discharge  *******************************%
%******************* 2b. Rotor-stator interaction tones ******************%

%*************************************************************************%
%***************** a.  RMS normalized acoustic pressure ******************%
%*****************         p*^2 = p^2/(rho^2*a^4)      *******************%
%*************************************************************************

% -  Overall Power 
K_dis_T = 2.643*10^(-4);

G = [1 0.580; 2.50 0.820];
G_dis_T = G(i,j);

a_dis_T = a_inlet_T;

b_dis_T = b_inlet_B;

F_dis_T = F_dis_B;

S_dis_T = S_inlet_IT;

[Overall_power_fan_2b] = compute_overall_power_fan(K_dis_T,G_dis_T,s_ad,a_dis_T,Mm,b_dis_T,mdot_ad,A_fan_ad,delta_T_ad,F_dis_T);

% - Directivity function D(theta)
directivity_level_log10D_DisTone = [-3.45 -3.05 -2.65 -2.25 -1.85 -1.45 -1.05 -0.65 -0.35 -0.05 0.15 0.35 0.45 0.45 0.25 -0.10 -0.45 -0.85 -1.35];

%Coefficients (with 95% confidence bounds):
       p1 =  -1.717e-06;
       p2 =   0.0001683;
       p3 =     0.03644;
       p4 =      -3.448;
       
D_dis_T = 10^(p1*(theta)^3 + p2*(theta)^2 + p3*(theta)+ p4);

% - Spectrum function S(eta)
S_dis_T = S_inlet_IT;

%--> compute

p_2_fan_2b = ((A_fan_ad*Overall_power_fan_2b)/(4*pi*r_ad^2))*(D_dis_T*S_dis_T)/(1-M_inf*cosd(theta)^4);



%This function compute fan noise from design parameter.

%*************************************************************************%
  % ********  *******  TOTAL FAN RMS acooustic pressure  ******* ******* %
  
p_2_fan = ne*(p_2_fan_1a + p_2_fan_1b + p_2_fan_1c + p_2_fan_1d_8 + p_2_fan_1d_4 + p_2_fan_1d_2 + p_2_fan_2a + p_2_fan_2b);

end
