function [rho_0,T_0,p_0,a_0,M_0,time_v,t_v,r_v,theta_v,phi_v,Vj,Aj,T0j,rhoj,pj,Mj,delta,N,l,delta_T,mdot_off] = flyover(V,h,T,noise_time,Max_T_dry,mdot_proj,NcL_proj,ab,beta_cL,beta_cH,TIT,A_0,A_e,L_conv,L_div,div_angle,T0_e_ab,mdot_ab)

%This function defines a flyover trajectory at constant speed, altitude and
%thrust.

% IN: Flight path, Thrust --> OUT: - noise measurement data (t,r,theta,phi), 
%                                  - jet noise parameters (Aj1,Vj1,Tj1,rhoj1,pj1,Mj1,delta)
%                                  - fan noise parameters (N,l,delta_T)

%% ******************** Coordinate reference system ***********************

%--> Axis
 
x = 0:0.1:10;                           %Distance along runaway centerline [Km]
y = -0.5:0.1:0.5;               %Distance across runaway centreline [Km]
z = 0:0.1:3.5;              %Altitude [Km] 

% figure(3)

% xlabel('x - [Distance along runaway centerline]','interpreter','latex')
% ylabel('y - [Distance across runaway centreline]','interpreter','latex') 
% zlabel('z - [Altitude]','interpreter','latex')
 
x_rw = 0:0.1:10;
y_rw = zeros(1,length(x_rw));
z_rw = zeros(1,length(x_rw));
% cen = plot3(x_rw,y_rw,z_rw,'LineWidth',2,'Color','b');%Runaway centreline

%--> Runaway
v = [x_rw(1) -0.10; x_rw(end) -0.10; x_rw(end) 0.10; x_rw(1) 0.10];
f = [1 2 3 4];

% run = patch('Faces',f,'Vertices',v,'FaceColor','k','FaceAlpha',.2);

% axis([x_rw(1) x_rw(end) -0.5 0.5 0 3.5])
% axis([0 3.5 -0.5 0.5 0 3.5])
% xticks([-4 -3 -2 -1 0 1 2 3 4 5 6 7 8 9 10])
% xticklabels({'-4000 m','-3000 m','-2000 m','-1000 m','0 m','1000 m','2000 m','3000 m','4000 m','5000 m' ,'6000 m','7000 m','8000 m','9000 m','10000 m'})
% xticks([0 0.5 1 1.5 2 2.5 3 3.5])
% xticklabels({'0 m','500 m','1000 m','1500 m','2000 m', '2500 m','3000 m', '3500 m'})
% yticks([-0.5 -0.4 -0.3 -0.2 -0.1 0 0.1 0.2 0.3 0.4 0.5])
% yticklabels({'-500 m','-400 m','-300 m','-200 m','-100 m','0 m','100 m','200 m','300 m' ,'400 m','500 m'})
% yticks([-0.5 -0.25 0 0.25 0.5])
% yticklabels({'-500 m','-0.250 m','0 m','250 m','500 m'})

% xticks([x(1) x(end)])
% xticklabels({'  ','  '})
% yticks([y(1) y(end)])
% yticklabels({'  ','  '})

% zticks([0 0.5 1.0 1.5 2.0 2.5 3.0 3.5])
% zticklabels({'0 m','500 m','1000 m','1500 m','2000 m', '2500 m','3000 m', '3500 m'})
% xlabel('x -[Distance along runaway centerline]','interpreter','latex')
% ylabel('y - [Distance across runaway centreline]','interpreter','latex') 
% zlabel('z - [Altitude]','interpreter','latex')
% set(gca,'FontSize',10)
% set(0,'DefaultAxesFontName', 'Euphemia')
% grid on

%--> Reference points
% hold on

%Flyover validation point
x_v = x_rw(end)/2; %Validation point is set at the middle of runaway
y_v = 0;
z_v = 0;

hold on
%plot3(x_v,y_v,z_v,'Color','k','Marker', '*','LineWidth',1.5);


%% *************************** Flight path ********************************
    
dt = 0.01; %Time interval for simulation

% Starting point
x_air_start = 0;
y_air_start = 0; 
z_air_start = h/1000; %[Km]

% Simulation time
t = x_rw(end)*1000/V; %[s]

vx = V;
vy = 0;
vz = 0;

% Ending point 
x_air_end = x_air_start+(vx*t)/1000; %[Km]
y_air_end = y_air_start+(vy*t)/1000; %[Km]
z_air_end = z_air_start+(vz*t)/1000; %[Km]

np = t/dt; %Number of points for simulation
time_vector = 1:np; %Time vector

x_pt = linspace(x_air_start,x_air_end,np);
y_pt = linspace(y_air_start,y_air_end,np);
z_pt = linspace(z_air_start,z_air_end,np);


%Angle between flight vector and engine inlet axis [deg]
delta = 0;

% --> Engine performance 
    
   [rho_0,T_0,p_0,a_0,M_0] = atmospheric_model(round(h),V);
   
% Afterburner OFF
% Hyp: 
% - critic nozzle: Mt = 1
   
[Aj,Vj,rhoj,T0j,pj,Mj,mdot_off,NcL_off,delta_T] = TJab_off(ab,T,V,h,T_0,p_0,M_0,Max_T_dry,beta_cL,beta_cH,TIT,A_0,A_e,mdot_proj,L_conv,L_div,div_angle,T0_e_ab,mdot_ab);
   
   if T > Max_T_dry
   N = NcL_proj; % On-design condition
   else
   N = (NcL_off)*NcL_proj; % Off-design condition
   end
 
   if h > 1 % Altitude index correction
        l = 1;
   else 
        l = 2;
   end
    
%Identification of flyover point time instant
t_v = find(abs(x_pt - x_v) == min(abs(x_pt - x_v)));

%-->  Distance and directivity 
    
    dx = abs(x_pt - x_v)*1000; %[m]
    dy = abs(y_pt - y_v)*1000; %[m]
    dz = abs(z_pt - z_v)*1000; %[m]
    r_v = sqrt(dx.^2+dy.^2+dz.^2); % Distance between observer and noise source [m]
    
    theta_ = asind(dz./r_v); % Polar directivity angle [deg]
 
    theta_1 = theta_(1:t_v);
    theta_2 = 180 - theta_(t_v+1:end);
    
    %Polar directivity angle [deg]
    theta_v(1:length(theta_1)) = (theta_1);
    theta_v(length(theta_1)+1:(length(theta_1)+length(theta_2))) = (theta_2);
    
    %Azimuthal directivity angle [deg]
    phi_v(1:length(theta_v))= 0; 
   

%%            %%%%%%%%%%%%%%%%%%%%% GIF image %%%%%%%%%%%%%%%%%%%%
              %   GIF image runs with dt = 0.5 s time interval   %
              
% graf = figure(3);
% xlabel('x','interpreter','latex')
% ylabel('y','interpreter','latex') 
% zlabel('z','interpreter','latex')
% axis tight manual % this ensures that getframe() returns a consistent size
% filename = 'Flyover.gif';

dt2 = 0.5/dt; 

for time = 1:dt2:time_vector(end)
%       ph = plot3(x_pt(time),y_pt(time),z_pt(time),'p','markerfacecolor','m','markeredgecolor','#7E2F8E','MarkerSize',10);
%       axis([0 10 -0.5 0.5 0 8])
%       daspect([1 1 1])
%       plot3(x_pt(time),y_pt(time),z_pt(time),'om','MarkerSize',1.5)
      
%       drawnow 
%       frame = getframe(graf); 
%       im = frame2im(frame); 
%       [imind,cm] = rgb2ind(im,256);
      
      %title({['Flyover at T = ',num2str(T),' N,',' h = ',num2str(h),' m'],['t = ', num2str(((time-1)*dt)),' s']},'interpreter','latex','FontWeight','bold','FontSize',15);
     
%       delete(ph)
%       str = ['g' 'k'];
      
if abs(t_v - time) > (noise_time/dt)/2
%     mic = plot3(x_v,y_v,z_v,'Color',str(2),'Marker', '*','LineWidth',1.5);
continue
else
%     mic = plot3(x_v,y_v,z_v,'Color',str(1),'Marker', 'o','MarkerSize',3,'LineWidth',1.5);
    
    time_v = (t_v -(noise_time/dt)/2):dt2:((noise_time/dt)/2)+t_v;
    
end

%       if time == 1 
%           imwrite(imind,cm,filename,'gif', 'Loopcount',inf); 
%       else 
%           imwrite(imind,cm,filename,'gif','WriteMode','append'); 
%       end 


end

hold on
%title({['Flyover'],['V = ',num2str(V,'%0.f'),' m/s,',' h = ',num2str(h,'%0.f'),' m, ',' T = ',num2str(T,'%0.f'),' N'],['t = ', num2str((time-1)*dt,'%0.f'),' s']},'interpreter','latex');
%title({['Flyover'],['V = ',num2str(V,'%0.f'),' m/s,',' t = ', num2str((time-1)*dt,'%0.f'),' s']},'interpreter','latex');
% title({'Validation flight path'},'interpreter','latex');
% plot3(x_pt,y_pt,z_pt,'m','LineWidth',1.5)
% legend('','','Microphone','Aircraft trajectory','interpreter','latex')


end

