%% MAIN

% This file computes LAmax, SEL, PNLTM and EPNL for take-off, landing and
% flyover trajectories.

% Grazia Piccirillo 

clear 
clc

%% Coordinate reference system

%--> Axis
x = -4:10;                         %Distance along runaway centerline [Km]
y = zeros(length(x));              %Distance across runaway centreline [Km]
z = zeros(length(x));              %Altitude [Km]

% figure('Name','Coordinate reference system')
% plot3(x,y,z,'LineWidth',2,'Color','b')%Runaway centreline

%--> Runaway centerline
x_rw = -3:0.1:3.5;
y_rw = zeros(1,length(x_rw));
z_rw = zeros(1,length(x_rw));

% plot3(x_rw,y_rw,z_rw,'LineWidth',2,'Color','b') 

%--> Runaway
v = [-3 -0.10; 3.5 -0.10; 3.5 0.10; -3 0.10];
f = [1 2 3 4];

% patch('Faces',f,'Vertices',v,'FaceColor','k','FaceAlpha',.2)

% axis([-4 9 -0.5 0.5 0 0.6])
% xticks([-4 -3 -2 -1 0 1 2 3 4 5 6 7 8 9 10])
% xticklabels({'-4000 m','-3000 m','-2000 m','-1000 m','0 m','1000 m','2000 m','3000 m','4000 m','5000 m' ,'6000 m','7000 m','8000 m','9000 m','10000 m'})
% yticks([-0.5 -0.4 -0.3 -0.2 -0.1 0 0.1 0.2 0.3 0.4 0.5])
% yticklabels({'-500 m','-400 m','-300 m','-200 m','-100 m','0 m','100 m','200 m','300 m' ,'400 m','500 m'})
% zticks([0 0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9 1])
% zticklabels({'0 m','100 m','200 m','300 m','400 m','500 m','600 m','700 m','800 m','900 m','1000 m'})
% xlabel('x - [Distance along runaway centerline]','interpreter','latex')
% ylabel('y - [Distance across runaway centreline]','interpreter','latex') 
% zlabel('z - [Altitude]','interpreter','latex')
% set(gca,'FontSize',10)
% set(0,'DefaultAxesFontName', 'Euphemia')
% grid on

% title('Coordinate reference system','interpreter','latex','FontWeight','bold','FontSize',15)

%--> Reference points
% hold on

%Approach threshold
y_at = -0.10:0.01:0.10;
x_at = zeros(length(y_at));
z_at = zeros(length(y_at));

% plot3(x_at,y_at,z_at,'LineWidth',1.25,'Color','#0072BD');
% text(-1.2,-0.2,0.02,'Approach threshold','Color','#0072BD','FontWeight','bold','interpreter','latex');

%ILS landing point
y_i = 0;
x_i = 0.3;
z_i = 0;

% plot3(x_i,y_i,z_i,'LineWidth',1.25,'Color','#7E2F8E','Marker','|');
% text(x_i+0.02,y_i+0.02,z_i+0.05,'ILS landing point','Color','#7E2F8E','FontWeight','bold','interpreter','latex');

%Approach noise measurement point
x_3 = -2;
y_3 = 0;
z_3 = 0;

% plot3(x_3,y_3,z_3,'Color','r','Marker', '*','LineWidth',1.5);
% text(x_3+0.02,y_3+0.02,z_3+0.02,'Approach noise measurement point','Color','r','FontWeight','bold','interpreter','latex');

%Start of take-off roll
y_t = -0.10:0.01:0.10;
x_t = ones(length(y_t))*0.1;
z_t = zeros(length(y_t));

% plot3(x_t,y_t,z_t,'LineWidth',1.25,'Color','#D95319');
% text(1.2,0.2,0.02,'Start of take-off roll','Color','#D95319','FontWeight','bold','interpreter','latex');

%Flyover noise measurement point
x_2 = 6.6;
y_2 = 0;
z_2 = 0;

% plot3(x_2,y_2,z_2,'Color','r','Marker', '*','LineWidth',1.5);
% text(x_2+0.02,y_2+0.02,z_2+0.02,'Flyover noise measurement point','Color','r','FontWeight','bold','interpreter','latex');

%Sideline noise measurement point
x_11 = 3.5;
y_11 = -0.45;
z_11 = 0;

% plot3(x_11,y_11,z_11,'Color','r','Marker', '*','LineWidth',1.5);
% text(2.5,y_11+0.02,z_11+0.05,'Sideline noise measurement point','Color','r','FontWeight','bold','interpreter','latex');

x_12 = 3.5;
y_12 = 0.45;
z_12 = 0;

% plot3(x_12,y_12,z_12,'Color','r','Marker', '*','LineWidth',1.5);
% text(2.5,y_12+0.02,z_12+0.05,'Sideline noise measurement point','Color','r','FontWeight','bold','interpreter','latex');

%ILS flight path
x_ILS = -2:0.1:0.3;
y_ILS = zeros(length(x_ILS));
z_ILS = -((x_ILS+2)*0.0543)+0.125;

% plot3(x_ILS,y_ILS,z_ILS,'Color','#7E2F8E','LineWidth',1.5)
% text(-3,0,0.25,'ILS flight path','Color','#7E2F8E','FontWeight','bold','interpreter','latex');

%% Input data

% -----------------------------AIRFRAME-----------------------------------%

%**************************** Delta Wing *********************************%

bw = 25.6; % Wingspan [m]
Sw = 358.25; % Wing surface [m^2]

%************************** Vertical Tail ********************************%

bv = 11.32; % Vertical tail heigth[m]
Sv = 33.91; % Wing surface (vertical tail) [m^2]

%************************** Landing gear *********************************%

%* Main:

n_strut_main = 2; % Num. of struts
n_wheels_main = 4; % Num. of wheels per strut
d_tyre_main = 1.2; % Tyre diameter [m]
l_strut_main = 2.5; % Strut length [m]

%* Forward:

n_strut_for = 1; % Num. of struts
n_wheels_for = 2; % Num. of wheels per strut
d_tyre_for = 0.787; % Tyre diameter [m]
l_strut_for = 3; % Strut length [m]

% ------------------------------ENGINE------------------------------------%

ne = 4; % Number of engine
d = 1.212; %Engine max diameter [m]
Ae = pi*d^2/4; %Engine reference area [m^2]

Max_T_wet = 169.2*1000; % Max thrust with AB [N]
Max_T_dry = 32000*4.45; %Max thrust w/o AB [N]


%%% ENGINE DATA %%%

    beta_cL = 3.237; % Low Compressor Ratio
    beta_cH = 4.788; % High Compressor Ratio
    TIT = 1012.15; % Turbine Inlet Temperature [K]
    
    A_0 = Ae; % Inlet area [m^2]
    A_e = 1.08; % Exit area [m^2]
     
    mdot_proj = 186; % Air mass flow [Kg/s] 
    
    L_conv = 0.431; % Convergent duct length [m]
    L_div = 2.1; % Divergent duct length [m]
    div_angle = 21; % Divergent opening angle [deg]                     
    
    %%% AFTERBURNER %%%
    
    T0_e_ab = 1700; % Afterburner exit temperature [K]
    mdot_ab = 0.417; % Afterburner propellant mass flow [kg/s]

%%% FAN or Compressor first stage DATA %%%
    
    A_fan = Ae; % Fan-inlet cross section area [m]
    d_rot = d; % Fan rotor diameter [m]
    
    i = 2; % i = 1 no inlet guide vanes, i = 2 inlet guide vanes
    
    nV = 32; % number of stator vanes
    B = 19; % Number of blades 
    C = 0.22; % Mean rotor blade chord [m]*
    s = 0.22; % Rotor-stator spacing [m]*
    
    Md = 1; % Fan rotor relative tip Mach number at design point*
  
    NcL_proj = 108; % Rotation speed - Low pressure spool [Hz]
    
    %Default values
%     N = 88; % Rotational speed [Hz]
%     l = 1; % l = 1 no inlet flow distorsion, l = 2 inlet flow distorsion (static & ground roll operation)
%     delta_T = 57.6; % Total temperature rise across fan


% -----------------CONFIGURATION & OPERATING CONDITION--------------------%

%****************************** Take off *********************************%

% ANP default fixed point profiles
distance_dep = [0 6967.5 12621.9 15264.7 16264.7 46509.2]*0.3048;
altitude_dep = [0 0 399.7 1000 1064.0 3000]*0.3048;
TAS_dep = [35 197.3 251.5 253.7 253.9 261.3]*0.5144;
T_dep = [39653 33394.3 31833.4 32000.1 18300 18300]*4.4482;

%****************************** Landing **********************************%

% ANP default fixed point profiles
altitude_app = [1000 858.6 0 0]*0.3048;
distance_app = (altitude_app/tand(3))+[0 0 7727.4 0]*0.3048;
CAS_app = [164 155.5 30 0]*0.5144;
T_app = [0.4*Max_T_dry 0.3*Max_T_dry 0.2*Max_T_dry 0.1*Max_T_dry];

%********************* Noise measurement duration ************************%
noise_time = 60; % noise duration [s]

p_ref = 2e-5; % Min acoustic pressure [Pa]
%% Trajectory

% Set trajectory by user 

prompt = 'Set trajectory: 1) TAKE-OFF 2)LANDING 3)FLYOVER \n'; 
traj = input(prompt);

if traj == 1
    
   [rho_0,T_0,p_0,a_0,M_0,time_side,t_side,r_side,theta_s,phi_s,time_fly,t_fly,r_fly,theta_f,phi_f,V,h_pt,T,Aj,Vj,T0j,rhoj,pj,Mj,delta,N,l,delta_T,mdot_off] = takeoff_fp(distance_dep,altitude_dep,TAS_dep,T_dep,noise_time,Max_T_dry,mdot_proj,NcL_proj,beta_cL,beta_cH,TIT,A_0,A_e,L_conv,L_div,div_angle,T0_e_ab,mdot_ab);
  
    % Set measurement point by user 
     prompt = 'Set measurement point: 1) SIDELINE 2)FLYOVER \n'; 
     mes_point = input(prompt);
     
     if mes_point == 1
         
         str = 'Sideline';
         %disp('Results for sideline noise measurement point')
         
         %Sideline data
         
         conf = 1; % Landing-gear extracted 
         
         rho_inf = rho_0(time_side);
         T_inf = T_0(time_side);
         M_inf = M_0(time_side);
         a_inf = a_0(time_side);
         
         V = V(time_side);
         h_m = h_pt(time_side);
         r_ = r_side(time_side);
         theta = theta_s(time_side);    
         phi = phi_s(time_side);
         
         T = T(time_side);
         Aj1 = Aj(time_side);
         Vj1 = Vj(time_side);
         Tj1 = T0j(time_side);
         pj1 = pj(time_side);
         rhoj1 = rhoj(time_side);
         Mj1 = Mj(time_side);
         delta = delta(time_side);
         
         N = N(time_side);
         l = l(time_side);
         delta_T = delta_T(time_side);
         mdot = mdot_off(time_side);
               
     else
         
         str = 'Flyover';
         %disp('Results for flyover noise measurement point')
         
         %Flyover data

         conf = 0; % Landing-gear retracted
         
         rho_inf = rho_0(time_fly);
         T_inf = T_0(time_fly);
         M_inf = M_0(time_fly);
         a_inf = a_0(time_fly);
         
         V = V(time_fly);
         h_m = h_pt(time_fly);
         r_ = r_fly(time_fly);
         theta = theta_f(time_fly);    
         phi = phi_f(time_fly);
         
         T = T(time_fly);
         Aj1 = Aj(time_fly);
         Vj1 = Vj(time_fly);
         Tj1 = T0j(time_fly);
         pj1 = pj(time_fly);
         rhoj1 = rhoj(time_fly);
         Mj1 = Mj(time_fly);
         delta = delta(time_fly);
         
         N = N(time_fly);
         l = l(time_fly);
         delta_T = delta_T(time_fly);
         mdot = mdot_off(time_fly);
         
     end
         
elseif traj == 2
    
   [rho_0,T_0,p_0,a_0,M_0,time_app,t_app,r_app,theta_a,phi_a,V,h_pt,T,Aj,Vj,T0j,rhoj,pj,Mj,delta,N,l,delta_T,mdot_off] = landing_fp(distance_app,altitude_app,CAS_app,T_app,noise_time,Max_T_dry,mdot_proj,NcL_proj,beta_cL,beta_cH,TIT,A_0,A_e,L_conv,L_div,div_angle,T0_e_ab,mdot_ab);
 
    str = 'Approach';
    %disp('Results for approach noise measurement point')
    
         %Approach data
         conf = 1; % Landing-gear extracted 
         
         rho_inf = rho_0(time_app);
         T_inf = T_0(time_app);
         M_inf = M_0(time_app);
         a_inf = a_0(time_app);
         
         V = V(time_app);
         h_m = h_pt(time_app);
         r_ = r_app(time_app);
         theta = theta_a(time_app);    
         phi = phi_a(time_app);
         
         T = T(time_app);
         Aj1 = Aj(time_app);
         Vj1 = Vj(time_app);
         Tj1 = T0j(time_app);
         pj1 = pj(time_app);
         rhoj1 = rhoj(time_app);
         Mj1 = Mj(time_app);
         delta = delta(time_app);
         
         N = N(time_app);
         l = l(time_app);
         delta_T = delta_T(time_app);
         mdot = mdot_off(time_app);
         
elseif traj == 3
    
     str = 'Flyover';
     
% V = 160*0.5144; % [m/s]
% h_s = [200 400 630 1000 2000 4000 6300 10000 16000 25000]*0.3048; %[m]
% T_s = [10000 20000 28000 32000]*4.4482; % [N]

     prompt = 'Set measurement point: Aircraft speed V [m/s] \n'; 
     V = input(prompt);
     
     prompt = 'Set measurement point: Aircraft altitude h [m] \n'; 
     h = input(prompt);
     
     prompt = 'Set measurement point: Aircraft thrust T [N] \n'; 
     T = input(prompt);
     
     ab = 0; % Afterburner OFF
     ab = 1; % Afterburner ON
     
         [rho_0,T_0,p_0,a_0,M_0,time_v,t_v,r_v,theta_v,phi_v,Vj_v,Aj_v,T0j_v,rhoj_v,pj_v,Mj_v,delta_v,N_v,l_v,delta_T_v,mdot_off] = flyover(V,h,T,noise_time,Max_T_dry,mdot_proj,NcL_proj,ab,beta_cL,beta_cH,TIT,A_0,A_e,L_conv,L_div,div_angle,T0_e_ab,mdot_ab);
    
         %Time interval noise data
         conf = 1;
         
         rho_inf = ones(1,length(time_v))*rho_0;
         T_inf = ones(1,length(time_v))*T_0;
         M_inf = ones(1,length(time_v))*M_0;
         a_inf = ones(1,length(time_v))*a_0;
         
         V = ones(1,length(time_v))*V;
         h_m = ones(1,length(time_v))*h;
         r_ = r_v(time_v);
         theta = theta_v(time_v);
         phi = phi_v(time_v);
         
         T = ones(1,length(time_v))*T;
         Aj1 = ones(1,length(time_v))*Aj_v;
         Vj1 = ones(1,length(time_v))*Vj_v;
         Tj1 = ones(1,length(time_v))*T0j_v;
         pj1 = ones(1,length(time_v))*pj_v;
         rhoj1 = ones(1,length(time_v))*rhoj_v;
         Mj1 = ones(1,length(time_v))*Mj_v;
         delta = ones(1,length(time_v))*(delta_v);
         
         N = ones(1,length(time_v))*(N_v);
         l = ones(1,length(time_v))*(1);
         mdot = ones(1,length(time_v))*(mdot_off);
         delta_T = ones(1,length(time_v))*(delta_T_v); 
end

%% Noise metrics

p_2_airframe = ones(24,(noise_time*2)+1);
p_2_jet = ones(24,(noise_time*2)+1);
p_2_mix = ones(24,(noise_time*2)+1);
p_2_shock = ones(24,(noise_time*2)+1);
p_2_fan = ones(24,(noise_time*2)+1);
p_2_tot = ones(24,(noise_time*2)+1);

SPL_airframe = ones(24,(noise_time*2)+1);
SPL_jet = ones(24,(noise_time*2)+1);
SPL_jet_mix = ones(24,(noise_time*2)+1);
SPL_jet_shock = ones(24,(noise_time*2)+1);
SPL_fan = ones(24,(noise_time*2)+1);
SPL_tot = ones(24,(noise_time*2)+1);

SPL_airframe_A = ones(24,(noise_time*2)+1);
SPL_jet_A = ones(24,(noise_time*2)+1);
SPL_fan_A = ones(24,(noise_time*2)+1);
SPL_tot_A = ones(24,(noise_time*2)+1);

OASPL_air = ones(1,(noise_time*2)+1);
OASPL_jet = ones(1,(noise_time*2)+1);
OASPL_fan = ones(1,(noise_time*2)+1);
OASPL = ones(1,(noise_time*2)+1);

% PNL_air = ones(1,(noise_time*2)+1);
% PNL_jet = ones(1,(noise_time*2)+1);
% PNL_fan = ones(1,(noise_time*2)+1);
PNL = ones(1,(noise_time*2)+1);

PNLT = ones(1,(noise_time*2)+1);
C_tone = ones(1,(noise_time*2)+1);

% LA_max_vec = ones(1,length(h_s));
% SEL_vel = ones(1,length(h_s));
% PNLTM_vec = ones(1,length(h_s));
% EPNL_vec = ones(1,length(h_s));

       
%% Noise metrics

for k = 1:(noise_time*2)+1 %Sampling time 0.5 s
 
    % Airframe noise
    [SPL_airframe(:,k),p_2_airframe(:,k)] = airframe_noise(conf,h_m(k),r_(k),rho_inf(k),T_inf(k),M_inf(k),a_inf(k),p_ref,phi(k),theta(k),bw,Sw,bv,Sv,n_strut_main,n_wheels_main,d_tyre_main,l_strut_main,n_strut_for,n_wheels_for,d_tyre_for,l_strut_for);

    % Jet noise
    [SPL_jet(:,k),SPL_jet_mix(:,k),SPL_jet_shock(:,k),p_2_jet(:,k),p_2_mix(:,k),p_2_shock(:,k)] = jet_noise(Ae,ne,r_(k),h_m(k),rho_inf(k),T_inf(k),M_inf(k),a_inf(k),p_ref,theta(k),Aj1(k),Vj1(k),rhoj1(k),Tj1(k),pj1(k),Mj1(k),delta(k));

    % Fan noise
    [SPL_fan(:,k),p_2_fan(:,k)] = fan_noise(ne,rho_inf(k),T_inf(k),M_inf(k),a_inf(k),p_ref,h_m(k),r_(k),theta(k),Ae,d_rot,A_fan,i,nV,N(k),B,C,s,l(k),Md,mdot(k),delta_T(k));

    % --> Total aircraft noise
    p_2_tot(:,k) = p_2_airframe(:,k)+ p_2_jet(:,k) + p_2_fan(:,k);
    %[SPL_tot(:,k)] = compute_SPL(p_2_tot(:,k)',rho_inf(k),a_inf(k),p_ref,T_inf(k),r_(k)); 
    
%- Centered frequency 1/3-octave
f = [50 63 80 100 125 160 200 250 315 400 500 630 800 1000 1250 1600 2000 2500 3150 4000 5000 6300 8000 10000]; %frequenze centrali tra 50 e 10000 Hz in 1/3 di ottava

%- Temperature [°C]
 T_inf_C(k) = T_inf(k) - 273;
 %T_inf_C = 15;

%- Relative humidity
RH = 0.7;

%- Losses [db/100m]
coeff_assorb(:,k) = Norm866(T_inf_C(k),RH,f);

%--> Total losses
coeff_assorb_tot(:,k) = coeff_assorb(:,k).*(r_(k)./100);

SPL_tot(:,k) = (10.*log10(p_2_tot(:,k))+20.*log10((rho_inf(k).*a_inf(k).^2)./p_ref))-coeff_assorb_tot(:,k); 


    %****** OSPL [dBA] ******%

     A_weight = [-30.2 -26.2 -22.5 -19.1 -16.1 -13.4 -10.9 -8.6 -6.6 -4.8 -3.2 -1.9 -0.8 0 0.6 1 1.2 1.3 1.2 1 0.5 -0.1 -1.1 -2.5]';
    
    % --> OASPL airframe noise [dBA]
    SPL_airframe_A(:,k)= SPL_airframe(:,k) + A_weight;
    OASPL_air(k) = 10*log10(sum(10.^(SPL_airframe_A(:,k)./10)));
    
    % --> OASPL jet noise [dBA]
    SPL_jet_A(:,k)= SPL_jet(:,k) + A_weight;
    OASPL_jet(k) = 10*log10(sum(10.^(SPL_jet_A(:,k)./10)));

    % --> OASPL fan noise [dBA]
    SPL_fan_A(:,k)= SPL_fan(:,k) + A_weight;
    OASPL_fan(k) = 10*log10(sum(10.^(SPL_fan_A(:,k)./10)));
    
    % --> OASPL total aircraft noise [dBA]
    SPL_tot_A(:,k)= SPL_tot(:,k) + A_weight;
    OASPL(k) = 10*log10(sum(10.^(SPL_tot_A(:,k)./10)));
  
    %****** PNL [PNdB] ******%
    
    % --> PNL total aircraft noise [PNdB]
    [PNL(k),PNLT(k),C_tone(k)] = compute_PNL(SPL_tot_A(:,k));
    
%     % Suppression due to 1/3 - octave bandsharing
% 
%      if k > 2 && k < (noise_time*2)-1
%      C_av(k) = sum(C_tone(k-2:k+2))/5;
%      end
end

%% LAmax [dBA]

%--> LA max (airframe noise)
     LA_max_air = max(OASPL_air);
     
%      figure( 'Name', 'OASPL airframe vs. Time' )
%      grid on
%      axis tight
%      time_axes = 0:0.5:noise_time;
%      xlabel('Time [s]','interpreter','latex')
%      ylabel('Sound Pressure Level [dBA]','interpreter','latex')
%      xticks(0:(noise_time*2))
%      xticklabels(time_axes)
%      title(['OASPL airframe vs. Time - ',str],'interpreter','latex');
%      

%--> LA max (jet noise)
     LA_max_jet = max(OASPL_jet);
     
%      figure( 'Name', 'OASPL jet vs. Time' )
%      grid on
%      axis tight
%      time_axes = 0:0.5:noise_time;
%      xlabel('Time for noise measurement [s]','interpreter','latex')
%      ylabel('Sound Pressure Level [dBA]','interpreter','latex')
%      xticks(0:(noise_time*2))
%      xticklabels(time_axes)
%      title(['OASPL time evolution - ',str],'interpreter','latex');

     
%--> LA max (fan noise)
     LA_max_fan = max(OASPL_fan);
     
%      figure( 'Name', 'OASPL fan vs. Time' )
%      grid on 
%      axis tight
%      time_axes = 0:0.5:noise_time;
%      xlabel('Time for noise measurement [s]','interpreter','latex')
%      ylabel('Sound Pressure Level [dBA]','interpreter','latex')
%      xticks(0:(noise_time*2))
%      xticklabels(time_axes)
%      title(['OASPL time evolution - ',str],'interpreter','latex');

%--> LA max (overall noise)
     LA_max = max(OASPL);
     
     figure( 'Name', 'OASPL vs. Time' );
     grid on 
     grid minor
     axis tight
     time_axes = 0:10:noise_time;
     xlabel('Time [s]','interpreter','latex')
     ylabel('Sound Pressure Level [dBA]','interpreter','latex')
     xticks(0:20:(noise_time*2))
     xticklabels(time_axes)
%      title(['OASPL time evolution - ',str],['V = ',num2str(V(1),'%.0f'),' m/s,',' h = ',num2str(h_m(1),'%.0f'),' m, ','T = ',num2str(T(1),'%.0f'),' N'],'interpreter','latex');
     title(['OASPL time evolution - ',str],'interpreter','latex');
     
% Interpolation OASPL    
time = 0:(noise_time*2);
nel = 10000; % number of point for interpolation
time_2 = linspace(0,noise_time*2,nel);
OASPL_int = spline(time,OASPL,time_2);
     
hold on
plot(linspace(0,noise_time*2,length(OASPL_int)),OASPL_int,'Color','k');

% --> SEL (overall noise) 

%Find kF & kL
kF = find(abs((LA_max-10)-OASPL_int)<0.01,1,'first');
kL = find(abs((LA_max-10)-OASPL_int)<0.01,1,'last');
dh = round(nel/(noise_time*2)); % discretization time interval
   
SEL = 10*log10(sum(10.^(OASPL_int(kF:2*dh:kL)./10)));

% if (isempty(kF))~= 0||(isempty(kL)~= 0)
% % Empirical relationship to derive SEL from LAmax (INM Handbook (V6) -
% % Section 8.3.3)
% SEL = LA_max + 7.19 + 7.73*log10((h/0.3048)/1000);
% end
     
hold on
yline(LA_max-10,'-','LAmax - 10 dBA');
plot(kF/dh,(LA_max-10),'Marker','x','LineWidth',2,'Color','b');
plot(kL/dh,(LA_max-10),'Marker','x','LineWidth',2,'Color','b');
     
legend('OASPL vs. Time',['LAmax = ',num2str(LA_max,'%.2f'),' [dBA]'],['kF = ',num2str((kF/(2*dh)),'%.0f'),' s',', kL = ',num2str((kL/(2*dh)),'%.0f'),' s'],'interpreter','latex','Location', 'SouthEast' );
     
% Noise contributions
figure( 'Name', 'Noise contributions' )

histogram('Categories',{'Total'},'BinCounts',LA_max,'FaceColor','b')
hold on
histogram('Categories',{'Airframe','Jet','Fan'},'BinCounts',[LA_max_air LA_max_jet LA_max_fan],'FaceColor','#4DBEEE')
ylabel('dBA')

% title(['{$ LA_{max} $} - ',str],['V = ',num2str(V(1),'%.0f'),' m/s,',' h = ',num2str(h_m(1),'%.0f'),' m, ','T = ',num2str(T(1),'%.0f'),' N'],'interpreter','latex')
title(['{$ LA_{max} $} - ',str],'interpreter','latex') 

% --> PNLTM (overall noise)
      PNLTM = max(PNLT);
      
     ind = find(PNLT == PNLTM);
      
     figure( 'Name', 'PNLT vs. Time' );
     grid on 
     grid minor
     axis tight
     time_axes = 0:10:noise_time;
     xlabel('Time [s]','interpreter','latex')
     ylabel('Sound Pressure Level [PNdB]','interpreter','latex')
     xticks(0:20:(noise_time*2))
     xticklabels(time_axes)
%      title(['PNLT time evolution - ',str],['V = ',num2str(V(1),'%.0f'),' m/s,',' h = ',num2str(h_m(1),'%.0f'),' m, ','T = ',num2str(T(1),'%.0f'),' N'],'interpreter','latex');
     title(['PNLT time evolution - ',str],'interpreter','latex');

% Interpolation PNLT    
time = 0:(noise_time*2);
nel = 10000; % number of point for interpolation
time_2 = linspace(0,noise_time*2,nel);
PNLT_int = spline(time,PNLT,time_2);
     
hold on
plot(linspace(0,noise_time*2,length(PNLT_int)),PNLT_int,'Color','k');

% --> EPNL (overall noise) 

     %Find kF & kL
     kF = find(abs((PNLTM-10)-PNLT_int)<0.1,1,'first');
     kL = find(abs((PNLTM-10)-PNLT_int)<0.1,1,'last');
     
     hold on
     yline(PNLTM-10,'-','PNLTM - 10 PNdB');
     plot(kF/dh,(PNLTM-10),'Marker','x','LineWidth',2,'Color','b');
     plot(kL/dh,(PNLTM-10),'Marker','x','LineWidth',2,'Color','b');
     
    legend('PNLT vs. Time',['PNLTM = ',num2str(PNLTM,'%.2f'),' [PNdB]'],['kF = ',num2str((kF/(2*dh)),'%.0f'),' s',', kL = ',num2str((kL/(2*dh)),'%.0f'),' s'],'interpreter','latex','Location', 'SouthEast' );
   
    EPNL = 10*log10(sum(10.^(PNLT_int(kF:dh:kL)./10)))-13;
